@@ -2,7 +2,7 @@ import contextlib
 import weakref
 import warnings
 
-from pytestqt.exceptions import TimeoutError
+from pytestqt.exceptions import TimeoutError, ScreenshotError
 from pytestqt.qt_compat import qt_api
 from pytestqt.wait_signal import (
     SignalBlocker,
@@ -39,6 +39,7 @@ class QtBot:
     .. automethod:: waitExposed
     .. automethod:: waitForWindowShown
     .. automethod:: stop
+    .. automethod:: screenshot
     .. automethod:: wait
 
     **Signals and Events**
@@ -88,7 +89,7 @@ class QtBot:
 
     .. staticmethod:: keyToAscii (key)
 
-        Auxiliary method that converts the given constant ot its equivalent ascii.
+        Auxiliary method that converts the given constant to its equivalent ascii.
 
         :param Qt.Key_* key: one of the constants for keys in the Qt namespace.
 
@@ -138,6 +139,17 @@ class QtBot:
 
     def __init__(self, request):
         self._request = request
+        # pep8 aliases. Set here to automatically use implementations defined in sub-classes for alias creation
+        self.add_widget = self.addWidget
+        self.capture_exceptions = self.captureExceptions
+        self.wait_active = self.waitActive
+        self.wait_exposed = self.waitExposed
+        self.wait_for_window_shown = self.waitForWindowShown
+        self.wait_signal = self.waitSignal
+        self.wait_signals = self.waitSignals
+        self.assert_not_emitted = self.assertNotEmitted
+        self.wait_until = self.waitUntil
+        self.wait_callback = self.waitCallback
 
     def _should_raise(self, raising_arg):
         ini_val = self._request.config.getini("qt_default_raising")
@@ -593,6 +605,56 @@ class QtBot:
 
     capture_exceptions = captureExceptions
 
+    def screenshot(self, widget, suffix="", region=None):
+        """
+        .. versionadded:: 4.1
+
+        Take a screenshot of the given widget and save it.
+
+        The file is saved in a test-specific directory using pytest's ``tmp_path``
+        fixture. The filename is ensured to be unique using a counter, and contains the
+        ``objectName()`` of the widget if set, as well as its class name. A custom
+        ``suffix`` can be given to add to the generated name.
+
+        :param QWidget widget:
+            The widget to take a screenshot of.
+        :param str suffix:
+            An optional suffix to add to the filename.
+        :param QRect region:
+            The region of the widget to screeshot. By default, the entire widget is
+            contained.
+        :returns:
+            A ``pathlib.Path`` object with the taken screenshot.
+        :raises ScreenshotError: if taking the screenshot or saving the file failed.
+        """
+        pixmap = widget.grab() if region is None else widget.grab(region)
+        if pixmap.isNull():
+            raise ScreenshotError("Got null pixmap from Qt")
+
+        tmp_path = self._request.getfixturevalue("tmp_path")
+
+        parts = ["screenshot", widget.__class__.__name__]
+        name = widget.objectName()
+        if name:
+            parts.append(name)
+        if suffix:
+            parts.append(suffix)
+
+        for i in range(1, 500):
+            counter = [] if i == 1 else [str(i)]
+
+            path = tmp_path / ("_".join(parts + counter) + ".png")
+            if path.exists():
+                continue
+
+            ok = pixmap.save(str(path))
+            if not ok:
+                raise ScreenshotError(f"Saving to {path} failed")
+
+            return path
+
+        raise ScreenshotError(f"Failed to find unique filename, last try: {path}")
+
     @staticmethod
     def keyClick(*args, **kwargs):
         qt_api.QtTest.QTest.keyClick(*args, **kwargs)
@@ -645,35 +707,6 @@ class QtBot:
     def mouseRelease(*args, **kwargs):
         qt_api.QtTest.QTest.mouseRelease(*args, **kwargs)
 
-    # pep-8 aliases
-
-    def add_widget(self, *args, **kwargs):
-        return self.addWidget(*args, **kwargs)
-
-    def wait_active(self, *args, **kwargs):
-        return self.waitActive(*args, **kwargs)
-
-    def wait_exposed(self, *args, **kwargs):
-        return self.waitExposed(*args, **kwargs)
-
-    def wait_for_window_shown(self, *args, **kwargs):
-        return self.waitForWindowShown(*args, **kwargs)
-
-    def wait_signal(self, *args, **kwargs):
-        return self.waitSignal(*args, **kwargs)
-
-    def wait_signals(self, *args, **kwargs):
-        return self.waitSignals(*args, **kwargs)
-
-    def assert_not_emitted(self, *args, **kwargs):
-        return self.assertNotEmitted(*args, **kwargs)
-
-    def wait_until(self, *args, **kwargs):
-        return self.waitUntil(*args, **kwargs)
-
-    def wait_callback(self, *args, **kwargs):
-        return self.waitCallback(*args, **kwargs)
-
 
 # provide easy access to exceptions to qtbot fixtures
 QtBot.SignalEmittedError = SignalEmittedError
@@ -721,7 +754,7 @@ class _WaitWidgetContextManager:
 
     def __init__(self, method_name, adjective_name, widget, timeout):
         """
-        :param str method_name: name ot the ``QtTest`` method to call to check if widget is active/exposed.
+        :param str method_name: name to the ``QtTest`` method to call to check if widget is active/exposed.
         :param str adjective_name: "activated" or "exposed".
         :param widget:
         :param timeout:
