@@ -4,7 +4,7 @@ from pytestqt.exceptions import TimeoutError
 from pytestqt.qt_compat import qt_api
 
 
-class _AbstractSignalBlocker(object):
+class _AbstractSignalBlocker:
     """
     Base class for :class:`SignalBlocker` and :class:`MultiSignalBlocker`.
 
@@ -17,7 +17,7 @@ class _AbstractSignalBlocker(object):
 
     """
 
-    def __init__(self, timeout=1000, raising=True):
+    def __init__(self, timeout=5000, raising=True):
         self._loop = qt_api.QtCore.QEventLoop()
         self.timeout = timeout
         self.signal_triggered = False
@@ -48,7 +48,7 @@ class _AbstractSignalBlocker(object):
             self._timer.start()
 
         if self.timeout != 0:
-            self._loop.exec_()
+            qt_api.exec(self._loop)
 
         if not self.signal_triggered and self.raising:
             raise TimeoutError(self._timeout_message)
@@ -181,8 +181,8 @@ class SignalBlocker(_AbstractSignalBlocker):
     .. automethod:: connect
     """
 
-    def __init__(self, timeout=1000, raising=True, check_params_cb=None):
-        super(SignalBlocker, self).__init__(timeout, raising=raising)
+    def __init__(self, timeout=5000, raising=True, check_params_cb=None):
+        super().__init__(timeout, raising=raising)
         self._signals = []
         self.args = None
         self.all_args = []
@@ -220,7 +220,7 @@ class SignalBlocker(_AbstractSignalBlocker):
             self._loop.quit()
 
     def _cleanup(self):
-        super(SignalBlocker, self)._cleanup()
+        super()._cleanup()
         for signal in self._signals:
             _silent_disconnect(signal, self._quit_loop_by_signal)
         self._signals = []
@@ -265,7 +265,7 @@ class SignalAndArgs:
     def _get_readable_signal_with_optional_args(self):
         args = repr(self.args) if self.args else ""
 
-        # remove signal parameter signature, e.g. turn "some_signal(QString,int)" to "some_signal", because we're adding
+        # remove signal parameter signature, e.g. turn "some_signal(str,int)" to "some_signal", because we're adding
         # the actual parameters anyways
         signal_name = self.signal_name
         signal_name = signal_name.partition("(")[0]
@@ -304,8 +304,8 @@ class MultiSignalBlocker(_AbstractSignalBlocker):
     .. automethod:: wait
     """
 
-    def __init__(self, timeout=1000, raising=True, check_params_cbs=None, order="none"):
-        super(MultiSignalBlocker, self).__init__(timeout, raising=raising)
+    def __init__(self, timeout=5000, raising=True, check_params_cbs=None, order="none"):
+        super().__init__(timeout, raising=raising)
         self._order = order
         self._check_params_callbacks = check_params_cbs
         self._signals_emitted = (
@@ -559,7 +559,7 @@ class MultiSignalBlocker(_AbstractSignalBlocker):
             if potential_callback:
                 callback_name = self.get_callback_name(potential_callback)
                 if callback_name:
-                    signal_str_repr += " (callback: {})".format(callback_name)
+                    signal_str_repr += f" (callback: {callback_name})"
 
         return signal_str_repr
 
@@ -569,7 +569,7 @@ class MultiSignalBlocker(_AbstractSignalBlocker):
                 return signal
 
     def _cleanup(self):
-        super(MultiSignalBlocker, self)._cleanup()
+        super()._cleanup()
         for i in range(len(self._signals)):
             signal = self._signals[i]
             slot = self._slots[i]
@@ -579,7 +579,7 @@ class MultiSignalBlocker(_AbstractSignalBlocker):
         del self._slots[:]
 
 
-class SignalEmittedSpy(object):
+class SignalEmittedSpy:
     """
     .. versionadded:: 1.11
 
@@ -611,12 +611,10 @@ class SignalEmittedSpy(object):
                     "arguments %r" % (self.signal, list(self.args))
                 )
             else:
-                raise SignalEmittedError(
-                    "Signal %r unexpectedly emitted" % (self.signal,)
-                )
+                raise SignalEmittedError(f"Signal {self.signal!r} unexpectedly emitted")
 
 
-class CallbackBlocker(object):
+class CallbackBlocker:
 
     """
     .. versionadded:: 3.1
@@ -628,7 +626,7 @@ class CallbackBlocker(object):
     :ivar int timeout: maximum time to wait for the callback to be called.
 
     :ivar bool raising:
-        If :class:`TimeoutError` should be raised if a timeout occured.
+        If :class:`TimeoutError` should be raised if a timeout occurred.
 
         .. note:: contrary to the parameter of same name in
             :meth:`pytestqt.qtbot.QtBot.waitCallback`, this parameter does not
@@ -643,7 +641,7 @@ class CallbackBlocker(object):
         the callback wasn't called at all.
     """
 
-    def __init__(self, timeout=1000, raising=True):
+    def __init__(self, timeout=5000, raising=True):
         self.timeout = timeout
         self.raising = raising
         self.args = None
@@ -668,7 +666,7 @@ class CallbackBlocker(object):
         if self._timer is not None:
             self._timer.timeout.connect(self._quit_loop_by_timeout)
             self._timer.start()
-        self._loop.exec_()
+        qt_api.exec(self._loop)
         if not self.called and self.raising:
             raise TimeoutError("Callback wasn't called after %sms." % self.timeout)
 
